AdminLTE 3 | Dashboard 2

# Dashboard v2

CPU Traffic 10 %
Likes 41,410
Sales 760
New Members 2,000

##### Monthly Recap Report

Sales: 1 Jan, 2014 - 30 Jul, 2014

Goal Completion

Add Products to Cart 160/200
Complete Purchase 310/400
Visit Premium Page 480/800
Send Inquiries 250/500

### US-Visitors Report

90,70,90,70,75,80,70

##### 8390

Visits
90,50,90,70,61,83,63

##### 30%

Referrals
90,50,90,70,61,83,63

##### 70%

Organic

### Direct Chat

3
Alexander Pierce 23 Jan 2:00 pm
Is this template really for free? That's unbelievable!
Sarah Bullock 23 Jan 2:05 pm
You better believe it!
Alexander Pierce 23 Jan 5:37 pm
Working with AdminLTE on a great new app! Wanna join?
Sarah Bullock 23 Jan 6:10 pm
I would love to.

- Count Dracula 2/28/2015 How have you been? I was...
- Sarah Doe 2/23/2015 I will be waiting for...
- Nadia Jolie 2/20/2015 I'll call you back at...
- Nora S. Vans 2/10/2015 Where is your new...
- John K. 1/27/2015 Can I take a look at...
- Kenneth M. 1/4/2015 Never mind I found...

### Latest Members

8 New Members

- Alexander Pierce Today
- Norman Yesterday
- Jane 12 Jan
- John 12 Jan
- Alexander 13 Jan
- Sarah 14 Jan
- Nora 15 Jan
- Nadia 15 Jan

### Latest Orders

Order ID | Item | Status | Popularity
--- | --- | --- | ---
OR9842 | Call of Duty IV | Shipped | 90,80,90,-70,61,-83,63
OR1848 | Samsung Smart TV | Pending | 90,80,-90,70,61,-83,68
OR7429 | iPhone 6 Plus | Delivered | 90,-80,90,70,-61,83,63
OR7429 | Samsung Smart TV | Processing | 90,80,-90,70,-61,83,63
OR1848 | Samsung Smart TV | Pending | 90,80,-90,70,61,-83,68
OR7429 | iPhone 6 Plus | Delivered | 90,-80,90,70,-61,83,63
OR9842 | Call of Duty IV | Shipped | 90,80,90,-70,61,-83,63

Inventory 5,200
Mentions 92,050
Downloads 114,381
Direct Messages 163,921

### Browser Usage

- Chrome
- IE
- FireFox
- Safari
- Opera
- Navigator

### Recently Added Products

- Samsung TV $1800 Samsung 32" 1080p 60Hz LED Smart HDTV.
- Bicycle $700 26" Mongoose Dolomite Men's 7-speed, Navy Blue.
- Xbox One $350 Xbox One Console Bundle with Halo Master Chief Collection.
- PlayStation 4 $399 PlayStation 4 500GB Console (PS4)